@@ -968,10 +968,10 @@ def schedule_newsletter_sending(request, newsletter_id):
 
 def articles_category(request, slug):
     category = get_object_or_404(models.ArticleCategory, slug=slug)
-    #articles = get_article_class().objects.filter(category=category)
+    articles = get_article_class().objects.filter(category=category).order_by("-created")
     return render_to_response(
         'coop_cms/articles_category.html',
-        {'category': category},
+        {'category': category, "articles": articles},
         context_instance=RequestContext(request)
     )
 
@@ -1021,7 +1021,7 @@ def change_language(request):
             activate(lang_code)
                 
             if next_article:
-                next = reverse('coop_cms_view_article', args=[next_article.slug])
+                next = next_article.get_absolute_url()
             else:
                 next = localeurl_utils.locale_path(path, lang_code)
 
